Description Usage Arguments Details Value Examples
Creates a timestamped results directory.
1 | makeResultDir(path = NULL, keep_images = 0)
|
path |
A |
keep_images |
A |
makeResultDir creates a timestamped results
directory in the current working directory or in the path specified using
path.
By default, when the HTML report is generated, the images used in the
report are removed. If keep_images is set to 1 in the configuration
file (see importConfig), then a folder called images
is created as a subdirectory of the results directory. All of the images
used in the HTML report will then be stored in this subdirectory.
name of the timestamped results directory
1 2 3 4 5 | # With no image subdirectory
makeResultDir(path=getwd())
# With image subdirectory
makeResultDir(path=getwd(), keep_images=1)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.